//+------------------------------------------------------------------+
//|                                                  RSI_EMA_MTF.mq4 |
//|                                                          Kalenzo |
//|                                      bartlomiej.gorski@gmail.com |
//+------------------------------------------------------------------+
#property copyright "Kalenzo"
#property link      "bartlomiej.gorski@gmail.com"
#property indicator_color1 DodgerBlue
#property indicator_color2 Lime
#property indicator_buffers 2

extern int     RsiPeriod = 9;
extern int     MaType = MODE_EMA;
extern int     MaPeriod = 12;
extern int     TimeFrame = 15;
extern bool    AlertsOn = true;
extern bool    AlertsOnCurrent = false;
extern string  AlertEmailSubject = "";

datetime       LastAlertTime       = -999999;

string         AlertTextCrossUp    = "RSI cross EMA UP";
string         AlertTextCrossDown  = "RSI cross EMA DOWN";
double rsi[],
       ema[],
       rsiTF[],
       emaTF[];
       
#property indicator_separate_window
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   IndicatorBuffers(4);
   
   SetIndexBuffer(0,rsi);
   SetIndexBuffer(1,ema);
   
   SetIndexStyle(0,DRAW_LINE,STYLE_SOLID,2);
   SetIndexStyle(1,DRAW_LINE,STYLE_SOLID,1);
   
   SetIndexBuffer(2,rsiTF);
   SetIndexBuffer(3,emaTF);
   
   IndicatorShortName("MTF RSI (" + tf() + ")");
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
//----
     int bbshift,limit,limitTF;
     limit=Bars;
     limitTF = iBars(Symbol(),TimeFrame);
     
     for(int i=0; i<limitTF; i++) rsiTF[i] = iRSI(Symbol(),TimeFrame,RsiPeriod,PRICE_CLOSE,i);
     for(int j=0; j<limitTF; j++) emaTF[j] = iMAOnArray(rsiTF,0,MaPeriod,0,MaType,j);
     
     for(int t=0; t<limit; t++)
     {
        bbshift = iBarShift(Symbol(),TimeFrame,Time[t]);
        rsi[t] = rsiTF[bbshift];
        ema[t] = emaTF[bbshift];
     }
        ProcessAlerts();
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Alert function                                                   |
//+------------------------------------------------------------------+
int ProcessAlerts()
  {
     if (AlertsOnCurrent)
        int AlertCandle = 0;
        else AlertCandle = 1;
     if (AlertCandle >= 0  &&  Time[0] > LastAlertTime)
     {
//---- Alert processing for crossover UP (indicator line crosses ABOVE signal line)
        if (rsi[AlertCandle] > ema[AlertCandle]  &&  rsi[AlertCandle+1] <= ema[AlertCandle+1])  
        {
           string AlertText = Symbol() + " " + tf() + ": " + AlertTextCrossUp;
           if (AlertsOn)               Alert(AlertText);
           if (AlertEmailSubject > "") SendMail(AlertEmailSubject, AlertText);
           LastAlertTime = Time[0];
        }
//---- Alert processing for crossover DOWN (indicator line crosses BELOW signal line)
        if (rsi[AlertCandle] < ema[AlertCandle]  &&  rsi[AlertCandle+1] >= ema[AlertCandle+1])  
        {
           AlertText = Symbol() + " " + tf() + ": " + AlertTextCrossDown;
           if (AlertsOn)               Alert(AlertText);
           if (AlertEmailSubject > "") SendMail(AlertEmailSubject, AlertText);
           LastAlertTime = Time[0];
        }
     }
  return(0);
  }
//+------------------------------------------------------------------+ 
//| Timeframe translation                                            |
//+------------------------------------------------------------------+
string tf()
  {
     switch(TimeFrame)
     {
        case PERIOD_M1:    return("M1");
        case PERIOD_M5:    return("M5");
        case PERIOD_M15:   return("M15");
        case PERIOD_M30:   return("M30");
        case PERIOD_H1:    return("H1");
        case PERIOD_H4:    return("H4");
        case PERIOD_D1:    return("D1");
        case PERIOD_W1:    return("W1");
        case PERIOD_MN1:   return("MN");
        default:           return("Unknown timeframe");
     }
  }
//+------------------------------------------------------------------+ 
//| Indicator end                                                    |
//+------------------------------------------------------------------+